AllowlistInstruction

Enum AllowlistInstruction 

pub enum AllowlistInstruction {
    InitializeAdminAuthority,
    UpdateAdminAuthority,
    AdminAddPrivateAllowlist,
    AdminRemovePrivateAllowlist,
    Thaw {
        user_system_account: Pubkey,
    },
    AdminAddPublicAllowedAccount,
    AdminAddPrivateAllowedAccount,
    AdminRemovePublicAllowedAccount,
    AdminRemovePrivateAllowedAccount,
    AdminFreeze,
    AdminBurn {
        amount: u64,
        decimals: u8,
    },
}

Variants



InitializeAdminAuthority

Initializes the allowlist admin account.

It creates a new system account.

This can only be called once.

The InitializeAdminAuthority instruction MUST be in the same Transaction as the program deployment Otherwise another party can acquire ownership of the uninitialized admin account.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [writable] The Admin’s Program Derived Account
  3. [] System Program


UpdateAdminAuthority

Updates the allowlist admin account.

This can only be called by the existing admin authority.

Accounts expected by this instruction:

  1. [signer] The current Admin Authority account
  2. [signer] The new Admin Authority account
  3. [writable] The Admin’s Program Derived Account


AdminAddPrivateAllowlist

Associates a Token Mint as a Private Instrument.

This can only be called by the existing admin authority.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [] The token mint for the private instrument
  4. [writable] The Private Allowlist’s Program Derived Account
  5. [] System Program


AdminRemovePrivateAllowlist

Changes Token Mint from a Public Instrument to a Private Instrument.

This can only be called by the existing admin authority.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [] The token mint for the private instrument
  4. [writable] The Private Allowlist’s Program Derived Account
  5. [] System Program


Thaw

Thaws the underlying Token Account of the provided system wallet account if the wallet is on the allow list.

Accounts expected by this instruction:

  1. [] The token mint
  2. [] The wallet system account Program Derived Address for the Public Instrument Allowlist
  3. [] The wallet system account Program Derived Address for the Private Instrument Allowlist
  4. [writable] The wallet’s Token Account for the Mint
  5. [] The token program
  6. [] The Allowlist PDA for the Freeze Authority

Fields

user_system_account: Pubkey

The wallet system account that is being thawed (e.g. the Token Account owner)



AdminAddPublicAllowedAccount

Adds a new account to the Public Instrument Allowlist, and can only be called by the Admin Authority.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [signer] The wallet system account to add to the allow list. Note: this can optionally be a signer.
  4. [] The wallet system account Program Derived Address for the Private Instrument Allowlist
  5. [] System Program


AdminAddPrivateAllowedAccount

Adds a new account to the Private Instrument Allowlist, and can only be called by the Admin Authority.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [signer] The wallet system account to add to the allow list. Note: this can optionally be a signer.
  4. [] The wallet system account Program Derived Address for the Private Instrument Allowlist
  5. [] The token mint for the private instrument
  6. [] System Program


AdminRemovePublicAllowedAccount

Removes an existing account from the allowlist, and can only be called by the Admin Authority.

This instruction WILL NOT freeze existing Token Accounts, which is instead done via AdminFreeze.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [] The wallet system account to remove from the allow list.
  4. [] The wallet system account Program Derived Address for the allow list


AdminRemovePrivateAllowedAccount

Removes an existing account from the allowlist, and can only be called by the Admin Authority.

This instruction WILL NOT freeze existing Token Accounts, which is instead done via AdminFreeze.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [] The wallet system account to remove from the allow list.
  4. [] The wallet system account Program Derived Address for the allow list
  5. [] The token mint for the private instrument


AdminFreeze

Freezes an Token Account, and can only be called by the Admin Authority.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [] The wallet system account
  4. [writable] The wallet’s Token Account for the Mint
  5. [] The token mint
  6. [] The token program
  7. [] The Allowlist PDA for the Freeze Authority


AdminBurn

Burns tokens by removing them from an account. If they account is frozen, it will unfreeze it first, and then refreeze it.

This instruction can only be called by the Admin Authority

The wallet address does NOT need to be on the allowlist to be burned.

Accounts expected by this instruction:

  1. [signer] The Admin Authority account
  2. [] The Admin’s Program Derived Account
  3. [] The wallet system account
  4. [writable] The wallet’s Token Account for the Mint
  5. [] The token mint
  6. [] The token program
  7. [] The Allowlist PDA for the Freeze Authority

Fields

amount: u64

The amount of tokens to burn.

decimals: u8

Expected number of base 10 digits to the right of the decimal place.